% This code models dynamics when L-A+ cells grow in lysine-limited chemostat
% close all;
% clear all;

global gL dL KL  nL dil rH cL L0
dil=0.0866; %dilution rate (per hr)
L0=20; %reservior hyp conc. (uM)
rH=0.30; %Hhyp release rate (fmole/cell/hr, measured from this chemostat experiment)
dL = 0.0021; % death rate (per hr, measured from this chemostat experiment)
cL = 5.4; % lysine consumption (fmole/new cell)
gL = 0.51; % max growth rate (per hr)
KL =2.1 ; % Monod constant (uM)
nL=3.2; %%Moser cooperative growth coefficient

tsstep=0.5; % time step for evaluating ODE
tspan=0:tsstep:30;% duration for evaluating ODE


%7/26 data:chemo#5
% initial condition (live cell density, hypoxanthine, lysine, dead cell density) 
c0=[1.4E6/1000000;0;14*20/19;3E4/1000000];

%experimental measurements: col 1=time; col 2= dead, col 3= live, col 4=hyp
data20160726_5=[0.0	3.0E+04	1.4E+06	0.0	14*20/19
6.0	4.7E+04	4.0E+06	4.1	1.192118227
12.3	1.2E+05	3.1E+06	8.5	1.782758621
22.0	5.0E+04	3.3E+06	10.5	0.856157635
26.0	6.0E+04	4.0E+06	10.7	0.639408867];

[t x]=ode23s(@ChemoRfunc,tspan, c0);

figure (1)
semilogy(t, x(:,1)*1E6, '-','color',[0.4 0.2 0])
hold on
semilogy(t, x(:,4)*1E6,'-','color',[0.8 0.6 0.6])
semilogy(data20160726_5(:,1), data20160726_5(:,3), 'o','color',[0.4 0.2 0])
semilogy(data20160726_5(:,1), data20160726_5(:,2), 'o','color',[0.8 0.6 0.6])
hold off
xlabel('hours')
ylabel('cell density (/ml)')
set(gca, 'ticklength', [0.025 0.05])

figure (2)
plot(t, x(:,2), 'b-')
hold on
plot(data20160726_5(:,1), data20160726_5(:,4), 'bo')
plot(data20160726_5(:,1), data20160726_5(:,5), 'ko')
plot(t, x(:,3), 'k-')
hold off
xlabel('hours')
ylabel('Metabolite (uM)')
legend('blue Hyp','black Lys')
set(gca, 'ticklength', [0.025 0.05])





